bash
Keyboard shortcuts for bash cursor movement:

- Ctrl + A *Go to the beginning of the line you are currently typing on*
- Ctrl + E *Go to the end of the line you are currently typing on*
- Alt + F *Move cursor forward one word on the current line*
- Alt + B *Move cursor backward one word on the current line*

Keyboard shortcuts for line command line manipulation:

- Ctrl + U *Clears the line before the cursor position. If you are at the end of the line, clears the entire line.*
- Ctrl + K *Clear the line after the cursor*
- Ctrl + W *Delete the word before the cursor*
- Ctrl + T *Swap the last two characters before the cursor*
- Esc + T *Swap the last two words before the cursor*

General Keyboard shortcuts:

- Ctrl + L *Clears the Screen, similar to the clear command*
- Ctrl + H *Same as backspace*
- Ctrl + R *Let's you search through previously used commands*
- Ctrl + C *Kill whatever you are running*
- Ctrl + D *Exit the current shell*
- Ctrl + Z *Puts whatever you are running into a suspended background process. fg restores it.*
